Index: webrtc/p2p/base/p2ptransportchannel.cc |
diff --git a/webrtc/p2p/base/p2ptransportchannel.cc b/webrtc/p2p/base/p2ptransportchannel.cc |
index 66532411b29f5241c6b0f163d87c91d7ba9cbe2a..8fb33e58cb99934351c1f4c14de77f3dec0d1509 100644 |
--- a/webrtc/p2p/base/p2ptransportchannel.cc |
+++ b/webrtc/p2p/base/p2ptransportchannel.cc |
@@ -390,10 +390,13 @@ void P2PTransportChannel::SetRemoteIceCredentials(const std::string& ice_ufrag, |
candidate.set_password(ice_pwd); |
} |
} |
// We need to update the credentials for any peer reflexive candidates. |
for (Connection* conn : connections_) { |
- conn->MaybeSetRemoteIceCredentials(ice_ufrag, ice_pwd); |
+ conn->MaybeSetRemoteIceCredentialsAndGeneration(remote_ice_parameters_); |
honghaiz3
2016/04/18 16:12:37
Why does this need to pass all ice parameters and
Taylor Brandstetter
2016/04/18 23:30:01
You're right. I don't remember what I was thinking
|
} |
+ // Updating the remote ICE candidate generation could change the sort order. |
+ RequestSort(); |
} |
void P2PTransportChannel::SetRemoteIceMode(IceMode mode) { |
@@ -390,10 +390,13 @@ void P2PTransportChannel::SetRemoteIceCredentials(const std::string& ice_ufrag, |
} |
} |
- // We need to update the credentials for any peer reflexive candidates. |
+ // We need to update the credentials and generation for any peer reflexive |
+ // candidates. |
for (Connection* conn : connections_) { |